@@ -2,7 +2,7 @@ package Inline;
 
 use strict;
 require 5.005;
-$Inline::VERSION = '0.44_01';
+$Inline::VERSION = '0.45_01';
 
 use AutoLoader 'AUTOLOAD';
 use Inline::denter;
@@ -23,7 +23,7 @@ $Inline::languages = undef; #needs to be global for AutoLoaded error messages
 
 our $did = '_Inline'; # Default Inline Directory
 
-my %shortcuts = 
+my %shortcuts =
   (
    NOCLEAN =>      [CLEAN_AFTER_BUILD => 0],
    CLEAN =>        [CLEAN_BUILD_AREA => 1],
@@ -42,7 +42,7 @@ my %shortcuts =
    SITE_INSTALL => undef,  # No longer supported.
   );
 
-my $default_config = 
+my $default_config =
   {
    NAME => '',
    AUTONAME => -1,
@@ -78,7 +78,7 @@ sub import {
     my $o;
     my ($pkg, $script) = caller;
     # Not sure what this is for. Let's see what breaks.
-    # $pkg =~ s/^.*[\/\\]//; 
+    # $pkg =~ s/^.*[\/\\]//;
     my $class = shift;
     if ($class ne 'Inline') {
 	croak M01_usage_use($class) if $class =~ /^Inline::/;
@@ -165,7 +165,7 @@ sub bind {
       unless ($language_id =~ /^\S+$/ and $language_id !~ /\n/);
     $code = shift or croak M03_usage_bind();
     @config = @_;
-	
+
     my $next = 0;
     for (@config) {
 	next if $next++ % 2;
@@ -185,7 +185,7 @@ sub bind {
 #==============================================================================
 # Process delayed objects that don't have source code yet.
 #==============================================================================
-# This code is an ugly hack because of the fact that you can't use an 
+# This code is an ugly hack because of the fact that you can't use an
 # INIT block at "run-time proper". So we kill the warning for 5.6+ users
 # and tell them to use a Inline->init() call if they run into problems. (rare)
 my $lexwarn = ($] >= 5.006) ? 'no warnings;' : '';
@@ -257,7 +257,7 @@ sub glue {
 	eval "require $o->{INLINE}{ILSM_module}";
 	croak M05_error_eval('glue', $@) if $@;
         $o->push_overrides;
-	bless $o, $o->{INLINE}{ILSM_module};    
+	bless $o, $o->{INLINE}{ILSM_module};
 	$o->validate(@config);
     }
     else {
@@ -308,11 +308,11 @@ sub push_overrides {
             $o->{OVERRIDDEN}{$ilsm . "::$override"} =
               \&{$ilsm . "::$override"};
             *{$ilsm . "::$override"} =
-              *{$using_module . "::$override"};
+              \&{$using_module . "::$override"};
         }
     }
 }
-        
+
 #==============================================================================
 # Restore the modules original methods
 #==============================================================================
@@ -363,7 +363,7 @@ sub check_config {
 	my ($key, $value) = (shift, shift);
 	if (defined $default_config->{$key}) {
 	    if ($key =~ /^(WITH|USING)$/) {
-		croak M10_usage_WITH_USING() 
+		croak M10_usage_WITH_USING()
                   if (ref $value and ref $value ne 'ARRAY');
 		$value = [$value] unless ref $value;
 		$o->{CONFIG}{$key} = $value;
@@ -375,7 +375,7 @@ sub check_config {
 		$value = abs_path($value);
 	    }
 	    elsif ($key eq 'NAME') {
-		croak M12_usage_NAME($value) 
+		croak M12_usage_NAME($value)
 		  unless $value =~ /^[a-zA-Z_](\w|::)*$/;
 	    }
 	    elsif ($key eq 'VERSION') {
@@ -409,7 +409,7 @@ sub fold_options {
     if ($o->{CONFIG}{AUTONAME} == -1) {
 	$o->{CONFIG}{AUTONAME} = length($o->{CONFIG}{NAME}) ? 0 : 1;
     }
-    $o->{API}{cleanup} = 
+    $o->{API}{cleanup} =
       ($o->{CONFIG}{CLEAN_AFTER_BUILD} and not $o->{CONFIG}{REPORTBUG});
 }
 
@@ -442,12 +442,12 @@ sub check_installed {
     pop @dirparts unless $dirparts[-1];
     push @dirparts, $file;
     my @endparts = splice(@dirparts, 0 - @pkgparts);
-    
+
     $dirparts[-1] = 'arch'
       if $dirparts[-2] eq 'blib' && $dirparts[-1] eq 'lib';
-    File::Spec->catfile(@endparts) eq $realname 
+    File::Spec->catfile(@endparts) eq $realname
       or croak M28_error_grokking_path($realpath);
-    $realpath = 
+    $realpath =
       File::Spec->catpath($volume,File::Spec->catdir(@dirparts),"");
 
     $o->{API}{version} = $o->{CONFIG}{VERSION};
@@ -459,11 +459,11 @@ sub check_installed {
     my $suffix = $Config{dlext};
     my $obj = File::Spec->catfile($realpath,'auto',$o->{API}{modpname},
                                   "$o->{API}{modfname}.$suffix");
-    croak M30_error_no_obj($o->{CONFIG}{NAME}, $o->{API}{pkg}, 
+    croak M30_error_no_obj($o->{CONFIG}{NAME}, $o->{API}{pkg},
 			   $realpath) unless -f $obj;
 
-    @{$o->{CONFIG}}{qw( PRINT_INFO 
-			REPORTBUG 
+    @{$o->{CONFIG}}{qw( PRINT_INFO
+			REPORTBUG
 			FORCE_BUILD
 			_INSTALL_
 		      )} = (0, 0, 0, 0);
@@ -483,7 +483,7 @@ sub load {
 
     if ($o->{CONFIG}{_INSTALL_}) {
 	my $inline = "$o->{API}{modfname}.inl";
-	open INLINE, "> $inline" 
+	open INLINE, "> $inline"
 	  or croak M24_open_for_output_failed($inline);
 	print INLINE "*** AUTOGENERATED by Inline.pm ***\n\n";
 	print INLINE "This file satisfies the make dependency for ";
@@ -509,7 +509,7 @@ sub load {
 
 	package $module;
 	push \@$ {module}::ISA, qw(Exporter DynaLoader);
-        sub dl_load_flags { $global } 
+        sub dl_load_flags { $global }
 	${module}::->bootstrap;
 END
     croak M43_error_bootstrap($module, $@) if $@;
@@ -577,7 +577,7 @@ sub handle_shortcuts {
 	else {
 	    croak M48_usage_shortcuts($option);
 	}
-    }    
+    }
 }
 
 #==============================================================================
@@ -612,7 +612,7 @@ __END__
 sub receive_code {
     my $o = shift;
     my $code = shift;
-    
+
     croak M02_usage() unless (defined $code and $code);
 
     if (ref $code eq 'CODE') {
@@ -631,7 +631,7 @@ sub receive_code {
 	else {
 	    croak M07_code_file_does_not_exist($code);
 	}
-    } 
+    }
     else {
 	$o->{API}{code} = $code;
     }
@@ -645,7 +645,7 @@ sub read_inline_file {
     my ($lang, $pkg) = @{$o->{API}}{qw(language_id pkg)};
     my $langfile = uc($lang);
     croak M59_bad_inline_file($lang) unless $langfile =~ /^[A-Z]\w*$/;
-    croak M60_no_inline_files() 
+    croak M60_no_inline_files()
       unless (defined $INC{File::Spec::Unix->catfile("Inline","Files.pm")} and
 	      $Inline::Files::VERSION =~ /^\d\.\d\d$/ and
 	      $Inline::Files::VERSION ge '0.51');
@@ -668,8 +668,8 @@ sub check_config_file {
     my ($DIRECTORY, %config);
     my $o = shift;
 
-    croak M14_usage_Config() if defined %main::Inline::Config::;
-    croak M63_no_source($o->{API}{pkg}) 
+    croak M14_usage_Config() if %main::Inline::Config::;
+    croak M63_no_source($o->{API}{pkg})
       if $o->{INLINE}{md5} eq $o->{API}{code};
 
     # First make sure we have the DIRECTORY
@@ -677,7 +677,7 @@ sub check_config_file {
 	croak M15_usage_install_directory()
 	  if $o->{CONFIG}{DIRECTORY};
 	my $cwd = Cwd::cwd();
-        $DIRECTORY = 
+        $DIRECTORY =
           $o->{INLINE}{DIRECTORY} = File::Spec->catdir($cwd, $did);
 	if (not -d $DIRECTORY) {
 	    _mkdir($DIRECTORY, 0777)
@@ -689,7 +689,7 @@ sub check_config_file {
 	  $o->{CONFIG}{DIRECTORY} || $o->find_temp_dir;
     }
 
-    $o->create_config_file($DIRECTORY) 
+    $o->create_config_file($DIRECTORY)
       if not -e File::Spec->catfile($DIRECTORY,"config");
 
     open CONFIG, "< ".File::Spec->catfile($DIRECTORY,"config")
@@ -744,8 +744,8 @@ sub create_config_file {
         my($v,$d,$f) = File::Spec->splitpath($inline);
         $f = "" if $f eq 'Inline.pm';
         $inline = File::Spec->catpath($v,$d,$f);
-        #my $INC = "-I$inline -I" . 
-        #          join(" -I", grep {(-d File::Spec->catdir($_,"Inline") or 
+        #my $INC = "-I$inline -I" .
+        #          join(" -I", grep {(-d File::Spec->catdir($_,"Inline") or
         #                             -d File::Spec->catdir($_,"auto","Inline")
 	  #		            )} @INC);
 	#system "$perl $INC -MInline=_CONFIG_ -e1 $dir"
@@ -762,7 +762,7 @@ sub create_config_file {
   LIB:
     for my $lib (@INC) {
         next unless -d File::Spec->catdir($lib,"Inline");
-        opendir LIB, File::Spec->catdir($lib,"Inline") 
+        opendir LIB, File::Spec->catdir($lib,"Inline")
           or warn(M21_opendir_failed(File::Spec->catdir($lib,"Inline"))), next;
 	while ($mod = readdir(LIB)) {
 	    next unless $mod =~ /\.pm$/;
@@ -777,7 +777,7 @@ sub create_config_file {
             warn($@), next if $@;
 	    eval "\$register=&Inline::${mod}::register";
 	    next if $@;
-	    my $language = ($register->{language}) 
+	    my $language = ($register->{language})
 	      or warn(M22_usage_register($mod)), next;
 	    for (@{$register->{aliases}}) {
 		warn(M23_usage_alias_used($mod, $_, $languages{$_})), next
@@ -836,7 +836,7 @@ sub check_module {
     my $auto_level = 2;
     while ($auto_level <= 5) {
 	if ($o->{CONFIG}{AUTONAME}) {
-	    $module2 = 
+	    $module2 =
 	      $module . '_' . substr($o->{INLINE}{md5}, 0, 2 + $auto_level);
 	    $auto_level++;
 	} else {
@@ -847,10 +847,10 @@ sub check_module {
 	my @modparts = split /::/, $module2;
 	$o->{API}{modfname} = $modparts[-1];
         $o->{API}{modpname} = File::Spec->catdir(@modparts);
-	$o->{API}{build_dir} = 
+	$o->{API}{build_dir} =
           File::Spec->catdir($o->{INLINE}{DIRECTORY},
                              'build',$o->{API}{modpname});
-        $o->{API}{install_lib} = 
+        $o->{API}{install_lib} =
           File::Spec->catdir($o->{INLINE}{DIRECTORY}, 'lib');
 
         my $inl = File::Spec->catfile($o->{API}{install_lib},"auto",
@@ -904,9 +904,9 @@ sub install {
 #	      $o->{CONFIG}{NAME} =~ /^$o->{API}{pkg}::\w(\w|::)+$/
 #	     );
 
-    my ($mod_name, $mod_ver, $ext_name, $ext_ver) = 
+    my ($mod_name, $mod_ver, $ext_name, $ext_ver) =
       ($o->{API}{pkg}, $ARGV[0], @{$o->{CONFIG}}{qw(NAME VERSION)});
-    croak M41_usage_install_version_mismatch($mod_name, $mod_ver, 
+    croak M41_usage_install_version_mismatch($mod_name, $mod_ver,
 					     $ext_name, $ext_ver)
       unless ($mod_ver eq $ext_ver);
     $o->{INLINE}{INST_ARCHLIB} = $ARGV[1];
@@ -921,7 +921,7 @@ sub install {
                                               $o->{API}{modpname});
     $o->{API}{directory} = $o->{INLINE}{DIRECTORY};
     my $cwd = Cwd::cwd();
-    $o->{API}{install_lib} = 
+    $o->{API}{install_lib} =
       File::Spec->catdir($cwd,$o->{INLINE}{INST_ARCHLIB});
     $o->{API}{location} =
       File::Spec->catfile($o->{API}{install_lib},"auto",$o->{API}{modpname},
@@ -935,7 +935,7 @@ sub install {
 #==============================================================================
 sub write_inl_file {
     my $o = shift;
-    my $inl = 
+    my $inl =
       File::Spec->catfile($o->{API}{install_lib},"auto",$o->{API}{modpname},
                           "$o->{API}{modfname}.inl");
     open INL, "> $inl"
@@ -956,7 +956,7 @@ sub write_inl_file {
 	       *Config, { (map {($_,$Config{$_})}
 			   (qw( archname osname osvers
 				cc ccflags ld so version
-			      ))), 
+			      ))),
 			  (apiversion => $apiversion),
 			},
 	      );
@@ -1027,7 +1027,7 @@ sub clean_build {
     while ($dir = readdir(BUILD)) {
         my $maybedir = File::Spec->catdir($prefix,$dir);
         if (($maybedir and -d $maybedir) and ($dir =~ /\w{36,}/)) {
-            $o->rmpath($prefix,$dir); 
+            $o->rmpath($prefix,$dir);
 	}
     }
 
@@ -1089,8 +1089,8 @@ END
     {
 	no strict 'refs';
 	%versions = map {eval "use $_();"; ($_, $ {$_ . '::VERSION'})}
-	qw (Digest::MD5 Parse::RecDescent 
-	    ExtUtils::MakeMaker File::Path FindBin 
+	qw (Digest::MD5 Parse::RecDescent
+	    ExtUtils::MakeMaker File::Path FindBin
 	    Inline
 	   );
     }
@@ -1103,7 +1103,7 @@ END
     %Inline::REPORTBUG_Perl_Config = ();
     %Inline::REPORTBUG_Module_Versions = ();
     print REPORTBUG Inline::denter->new()
-      ->indent(*REPORTBUG_Inline_Object, $o, 
+      ->indent(*REPORTBUG_Inline_Object, $o,
 	       *REPORTBUG_Perl_Config, \%Config::Config,
 	       *REPORTBUG_Module_Versions, \%versions,
 	      );
@@ -1123,7 +1123,7 @@ sub print_info {
 Information about the processing of your Inline $o->{API}{language_id} code:
 
 END
-    
+
     print STDERR <<END if ($o->{INLINE}{object_ready});
 Your module is already compiled. It is located at:
 $o->{API}{location}
@@ -1147,7 +1147,7 @@ and I\'ll install the executable as:
 $o->{API}{location}
 
 END
-    
+
     eval {
 	print STDERR $o->info;
     };
@@ -1235,7 +1235,7 @@ sub _rmtree {
 	    ($root) = $root =~ /(.*)/ if UNTAINT;
             rmdir($root) or croak M54_rmdir_failed($root);
         }
-        else { 
+        else {
 	    ($root) = $root =~ /(.*)/ if UNTAINT;
 	    unlink($root) or croak M55_unlink_failed($root);
         }
@@ -1248,12 +1248,12 @@ sub _rmtree {
 my $TEMP_DIR;
 sub find_temp_dir {
     return $TEMP_DIR if $TEMP_DIR;
-    
+
     my ($temp_dir, $home, $bin, $cwd, $env);
     $temp_dir = '';
     $env = $ENV{PERL_INLINE_DIRECTORY} || '';
     $home = $ENV{HOME} ? abs_path($ENV{HOME}) : '';
-    
+
     if ($env and
 	-d $env and
 	-w $env) {
@@ -1270,12 +1270,12 @@ sub find_temp_dir {
            -d File::Spec->catdir($bin,".Inline") and
            -w File::Spec->catdir($bin,".Inline")) {
         $temp_dir = File::Spec->catdir($bin,".Inline");
-    } 
+    }
     elsif ($home and
            -d File::Spec->catdir($home,".Inline") and
            -w File::Spec->catdir($home,".Inline")) {
         $temp_dir = File::Spec->catdir($home,".Inline");
-    } 
+    }
     elsif (defined $cwd and $cwd and
            -d File::Spec->catdir($cwd, $did) and
            -w File::Spec->catdir($cwd, $did)) {
@@ -1285,7 +1285,7 @@ sub find_temp_dir {
            -d File::Spec->catdir($bin, $did) and
            -w File::Spec->catdir($bin, $did)) {
         $temp_dir = File::Spec->catdir($bin, $did);
-    } 
+    }
     elsif (defined $cwd and $cwd and
 	   -d $cwd and
 	   -w $cwd and
@@ -1323,7 +1323,7 @@ sub _mkdir {
 sub M01_usage_use {
     my ($module) = @_;
     return <<END;
-It is invalid to use '$module' directly. Please consult the Inline 
+It is invalid to use '$module' directly. Please consult the Inline
 documentation for more information.
 
 END
@@ -1399,7 +1399,7 @@ END
 sub M07_code_file_does_not_exist {
     my ($file) = @_;
     return <<END;
-Inline assumes '$file' is a filename, 
+Inline assumes '$file' is a filename,
 and that file does not exist.
 
 END
@@ -1423,7 +1423,7 @@ END
 
 sub M10_usage_WITH_USING {
     return <<END;
-Config option WITH or USING must be a module name or an array ref 
+Config option WITH or USING must be a module name or an array ref
 of module names.
 
 END
@@ -1449,7 +1449,7 @@ sub M13_usage_VERSION {
     my ($version) = @_;
     return <<END;
 Invalid value for VERSION config option: '$version'
-Must be of the form '#.##'. 
+Must be of the form '#.##'.
 (Should also be specified as a string rather than a floating point number)
 
 END
@@ -1496,7 +1496,7 @@ sub M18_error_old_version {
     my ($old_version, $directory) = @_;
     $old_version ||= '???';
     return <<END;
-You are using Inline version $Inline::VERSION with a directory that was 
+You are using Inline version $Inline::VERSION with a directory that was
 configured by Inline version $old_version. This version is no longer supported.
 Please delete the following directory and try again:
 
@@ -1511,7 +1511,7 @@ sub M19_usage_language {
 Error. You have specified '$language' as an Inline programming language.
 
 I currently only know about the following languages:
-    ${ defined $Inline::languages ? 
+    ${ defined $Inline::languages ?
        \ join(', ', sort keys %$Inline::languages) : \ ''
      }
 
@@ -1639,7 +1639,7 @@ END
 sub M31_inline_open_failed {
     my ($file) = @_;
     return <<END;
-Can't open Inline validate file: 
+Can't open Inline validate file:
 
     $file
 
@@ -1804,7 +1804,7 @@ sub M48_usage_shortcuts {
 Invalid shortcut '$shortcut' specified.
 
 Valid shortcuts are:
-    VERSION, INFO, FORCE, NOCLEAN, CLEAN, UNTAINT, SAFE, UNSAFE, 
+    VERSION, INFO, FORCE, NOCLEAN, CLEAN, UNTAINT, SAFE, UNSAFE,
     GLOBAL, NOISY and REPORTBUG
 
 END
@@ -1851,7 +1851,7 @@ END
 sub M54_rmdir_failed {
     my ($dir) = @_;
     return <<END;
-Can't remove directory '$dir': 
+Can't remove directory '$dir':
 
 $!
 
@@ -1862,7 +1862,7 @@ END
 sub M55_unlink_failed {
     my ($file) = @_;
     return <<END;
-Can't unlink file '$file': 
+Can't unlink file '$file':
 
 $!
 
@@ -1890,7 +1890,7 @@ END
 
 sub M58_site_install {
     return <<END;
-You have specified the SITE_INSTALL command. Support for this option has 
+You have specified the SITE_INSTALL command. Support for this option has
 been removed from Inline since version 0.40. It has been replaced by the
 use of Inline::MakeMaker in your Makefile.PL. Please see the Inline
 documentation for more help on creating and installing Inline based modules.
@@ -1901,7 +1901,7 @@ END
 sub M59_bad_inline_file {
     my ($lang) = @_;
     return <<END;
-Could not find any Inline source code for the '$lang' language using 
+Could not find any Inline source code for the '$lang' language using
 the Inline::Files module.
 
 END
@@ -1930,8 +1930,8 @@ You are using a config file that was created by an older version of Inline:
     $config
 
 This file and all the other components in its directory are no longer valid
-for this version of Inline. The best thing to do is simply delete all the 
-contents of the directory and let Inline rebuild everything for you. Inline 
+for this version of Inline. The best thing to do is simply delete all the
+contents of the directory and let Inline rebuild everything for you. Inline
 will do this automatically when you run your programs.
 
 END
